@@ -61,6 +61,16 @@ class Turkish:
             history=self.history
         )
 
+    def is_from_able(self):
+        if len(self.history):
+            action = self.history[-1]['action']
+            auxiliary = self.history[-1]['kwargs'].get('auxiliary')
+
+            if action == 'unify_verbs' and auxiliary == 'bil':
+                return True
+
+        return False
+
     @proceed_letters
     def plural(self, **kwargs):
         ae = kwargs.get('ae')
@@ -334,7 +344,9 @@ class Turkish:
 
         ae = kwargs.get('ae')
 
-        if kwargs.get('negative', False):
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{ae}')
 
         self.word = concat(self.word, f'm{ae}k')
@@ -349,6 +361,7 @@ class Turkish:
             Note: For alternative usage of present continuous tense, check the function
                     present_continuous_alternative
         """
+        from_able = self.is_from_able()
 
         if not kwargs.get('negative', False):
             self.word = VERBS_HARDEN.get(self.word, self.word)
@@ -361,11 +374,12 @@ class Turkish:
                     MINOR_HARMONY[kwargs['last_vowel']['letter']]
                 )
         else:
-            self.word = concat(self.word, 'm')
-            self.word = concat(
-                self.word,
-                MINOR_HARMONY[kwargs['last_vowel']['letter']]
-            )
+            if not from_able:
+                self.word = concat(self.word, 'm')
+                self.word = concat(
+                    self.word,
+                    MINOR_HARMONY[kwargs['last_vowel']['letter']]
+                )
 
         self.word = concat(self.word, 'yor')
 
@@ -415,7 +429,10 @@ class Turkish:
                 * yapmaktayım
         """
         ae = kwargs.get('ae')
-        if kwargs.get('negative', False):
+
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{ae}')
 
         self.word = self.infinitive().to_string()
@@ -496,6 +513,9 @@ class Turkish:
         minor_harmony_letter_for_future = MINOR_HARMONY_FOR_FUTURE[kwargs['last_vowel']['letter']]
         minor_harmony_for_future = MINOR_HARMONY_FOR_FUTURE[minor]
 
+        ver_bil = self.word[-3:] in ('ver', 'bil')
+        from_able = self.is_from_able()
+
         if not kwargs.get('negative', False):
             self.word = soften(self.word)
 
@@ -503,11 +523,15 @@ class Turkish:
 
         if kwargs.get('question', False):
             if not kwargs.get('negative', False):
+
                 if self.word in ['al', 'kal']:
                     self.word = concat(self.word, 'ır')
                 else:
                     if not kwargs['last_letter_is_vowel']:
-                        self.word = concat(self.word, minor_harmony_letter_for_future)
+                        if ver_bil:
+                            self.word = concat(self.word, 'i')
+                        else:
+                            self.word = concat(self.word, minor_harmony_letter_for_future)
 
                     self.word = concat(self.word, 'r')
 
@@ -531,7 +555,9 @@ class Turkish:
                 else:
                     minor_harmony_letter_for_future = 'e'
 
-                self.word = concat(self.word, f'm{minor_harmony_letter_for_future}z')
+                if not from_able:
+                    self.word = concat(self.word, f'm{minor_harmony_letter_for_future}')
+                self.word = concat(self.word, f'z')
 
                 if not kwargs.get('plural', False):
                     if kwargs.get('person', 3) == 1:
@@ -554,7 +580,10 @@ class Turkish:
                     self.word = concat(self.word, 'ır')
                 else:
                     if not kwargs['last_letter_is_vowel']:
-                        self.word = concat(self.word, minor_harmony_letter_for_future)
+                        if self.word[-3:] in ('ver', 'bil'):
+                            self.word = concat(self.word, 'i')
+                        else:
+                            self.word = concat(self.word, minor_harmony_letter_for_future)
 
                     self.word = concat(self.word, 'r')
 
@@ -578,26 +607,34 @@ class Turkish:
 
                 if not kwargs.get('plural', False):
                     if kwargs.get('person', 3) == 1:
-                        self.word = concat(self.word, f'm{minor_harmony_letter_for_future}m')
+                        if not from_able:
+                            self.word = concat(self.word, f'm{minor_harmony_letter_for_future}')
+                        else:
+                            self.word = concat(self.word, f'm')
                     elif kwargs.get('person', 3) == 2:
-                        self.word = concat(self.word, 'm')
-                        self.word = concat(self.word, minor_harmony_letter_for_future)
+                        if not from_able:
+                            self.word = concat(self.word, 'm')
+                            self.word = concat(self.word, minor_harmony_letter_for_future)
                         self.word = concat(self.word, 'z')
                         self.word = concat(self.word, 's')
                         self.word = concat(self.word, MINOR_HARMONY[minor_harmony_for_future])
                         self.word = concat(self.word, 'n')
                     elif kwargs.get('person', 3) == 3:
-                        self.word = concat(self.word, f'm{minor_harmony_letter_for_future}z')
+                        if not from_able:
+                            self.word = concat(self.word, f'm{minor_harmony_letter_for_future}')
+                        self.word = concat(self.word, f'z')
                 else:
                     if kwargs.get('person', 3) == 1:
-                        self.word = concat(self.word, 'm')
-                        self.word = concat(self.word, minor_harmony_letter_for_future)
+                        if not from_able:
+                            self.word = concat(self.word, 'm')
+                            self.word = concat(self.word, minor_harmony_letter_for_future)
                         self.word = concat(self.word, 'y')
                         self.word = concat(self.word, MINOR_HARMONY[minor_harmony_for_future])
                         self.word = concat(self.word, 'z')
                     elif kwargs.get('person', 3) == 2:
-                        self.word = concat(self.word, 'm')
-                        self.word = concat(self.word, minor_harmony_letter_for_future)
+                        if not from_able:
+                            self.word = concat(self.word, 'm')
+                            self.word = concat(self.word, minor_harmony_letter_for_future)
                         self.word = concat(self.word, 'z')
                         self.word = concat(self.word, 's')
                         self.word = concat(self.word, MINOR_HARMONY[minor_harmony_for_future])
@@ -605,7 +642,9 @@ class Turkish:
                         self.word = concat(self.word, MINOR_HARMONY[minor_harmony_for_future])
                         self.word = concat(self.word, 'z')
                     elif kwargs.get('person', 3) == 3:
-                        self.word = concat(self.word, f'm{minor_harmony_letter_for_future}z')
+                        if not from_able:
+                            self.word = concat(self.word, f'm{minor_harmony_letter_for_future}')
+                        self.word = concat(self.word, f'z')
                         self.word = self.plural().to_string()
 
         return self.common_return(**kwargs)
@@ -617,7 +656,9 @@ class Turkish:
         """
         ae = kwargs['ae']
 
-        if kwargs.get('negative', False):
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{ae}')
 
         if 'vowel' in kwargs['last_letter']:
@@ -713,7 +754,10 @@ class Turkish:
         """
 
         ae = kwargs['ae']
-        if kwargs.get('negative', False):
+
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{ae}')
 
         minor = MINOR_HARMONY[kwargs['last_vowel']['letter']]
@@ -803,8 +847,9 @@ class Turkish:
 
         letter_a = kwargs['ae']
         letter_i = kwargs['letter_i']
+        from_able = self.is_from_able()
 
-        if kwargs.get('negative', False):
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{letter_a}')
 
         self.word = concat(self.word, f'm{letter_a}l{letter_i}')
@@ -836,7 +881,9 @@ class Turkish:
         letter_a = kwargs['ae']
         letter_i = kwargs['letter_i']
 
-        if kwargs.get('negative', False):
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{letter_a}')
 
         self.word = concat(self.word, f's{letter_a}')
@@ -867,8 +914,12 @@ class Turkish:
         letter_a = kwargs['ae']
         letter_i = kwargs['letter_i']
 
+        from_able = self.is_from_able()
+
         if kwargs.get('negative', False):
-            self.word = concat(self.word, f'm{letter_a}y{letter_a}')
+            if not from_able:
+                self.word = concat(self.word, f'y{letter_a}')
+            self.word = concat(self.word, f'y{letter_a}')
         else:
             self.word = VERBS_LOSING_VOWELS.get(self.word, self.word)
 
@@ -911,7 +962,9 @@ class Turkish:
 
         ae = kwargs['ae']
 
-        if kwargs.get('negative', False):
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{ae}')
 
         minor = MINOR_HARMONY[kwargs['last_vowel']['letter']]
@@ -954,7 +1007,9 @@ class Turkish:
         
         ae = kwargs['ae']
 
-        if kwargs.get('negative', False):
+        from_able = self.is_from_able()
+
+        if kwargs.get('negative', False) and not from_able:
             self.word = concat(self.word, f'm{ae}')
 
         actual_last_letter = last_letter(self.word)
@@ -982,7 +1037,6 @@ class Turkish:
                 self.word = self.plural().to_string()
 
         if kwargs.get('question', False):
-            actual_last_vowel = last_vowel(self.word)
             minor = MINOR_HARMONY[last_vowel(self.word)['letter']]
 
             self.word = concat(self.word, f' m{minor}')
@@ -1330,8 +1384,12 @@ class Turkish:
         """
         ae = kwargs.get('ae')
 
+        from_able = self.is_from_able()
+
         if kwargs.get('negative'):
-            self.word = concat(self.word, f'm{ae}y')
+            if not from_able:
+                self.word = concat(self.word, f'm{ae}')
+            self.word = concat(self.word, f'y')
         else:
             self.word = VERBS_HARDEN.get(self.word, self.word)
 
@@ -1376,10 +1434,14 @@ class Turkish:
         ae = kwargs['ae']
         letter_i = kwargs['letter_i']
         minor = MINOR_HARMONY[kwargs['last_vowel']['letter']]
+        from_able = self.is_from_able()
+
         self.word = VERBS_HARDEN.get(self.word, self.word)
 
         if kwargs.get('negative'):
-            self.word = concat(self.word, f'm{ae}y{letter_i}')
+            if not from_able:
+                self.word = concat(self.word, f'm{ae}')
+            self.word = concat(self.word, f'y{letter_i}')
         elif kwargs['last_letter_is_vowel']:
             self.word = concat(self.word, f'y{minor}')
         else:
@@ -1402,8 +1464,12 @@ class Turkish:
         ae = kwargs['ae']
         minor = MINOR_HARMONY[kwargs['last_vowel']['letter']]
 
+        from_able = self.is_from_able()
+
         if kwargs.get('negative'):
-            self.word = concat(self.word, f'm{ae}y')
+            if not from_able:
+                self.word = concat(self.word, f'm{ae}')
+            self.word = concat(self.word, f'y')
         elif kwargs['last_letter_is_vowel']:
             self.word = concat(self.word, f'y')
         else:
@@ -1424,7 +1490,13 @@ class Turkish:
         """
 
         ae = kwargs['ae']
-        self.word = concat(self.word, f'm{ae}d{ae}n')
+
+        from_able = self.is_from_able()
+
+        if not from_able:
+            self.word = concat(self.word, f'm{ae}')
+
+        self.word = concat(self.word, f'd{ae}n')
 
         return self.common_return(**kwargs)
 
@@ -1455,8 +1527,14 @@ class Turkish:
         """
 
         ae = kwargs['ae']
+
+        from_able = self.is_from_able()
+
         if kwargs.get('negative'):
-            self.word = concat(self.word, f'm{ae}y')
+            if not from_able:
+                self.word = concat(self.word, f'm{ae}')
+
+            self.word = concat(self.word, f'y')
         else:
             self.word = VERBS_HARDEN.get(self.word, self.word)
 
@@ -1480,8 +1558,13 @@ class Turkish:
         ae = kwargs['ae']
         letter_i = kwargs['letter_i']
 
+        from_able = self.is_from_able()
+
         if kwargs.get('negative'):
-            self.word = concat(self.word, f'm{ae}y')
+            if not from_able:
+                self.word = concat(self.word, f'm{ae}')
+
+            self.word = concat(self.word, f'y')
         else:
             self.word = VERBS_HARDEN.get(self.word, self.word)
 
